@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 3651 2010-09-29 10:51:05Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 3660 2010-10-01 12:41:57Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -19,6 +19,7 @@ class ScriptLibInfo
 	
 	// Javascriptライブラリ(DBでの設定値)
 	// ベースライブラリ
+	const LIB_JQUERY				= 'jquery';
 	const LIB_JQUERY_UI				= 'jquery-ui';
 	const LIB_JQUERY_UI_PLUS		= 'jquery-ui-plus';
 	const LIB_FCKEDITOR				= 'fckeditor';
@@ -146,7 +147,7 @@ class ScriptLibInfo
 	static function getJQueryFilename($type = 0)
 	{
 		$filename = '';
-		if ($type == 0){	// Core
+		if ($type == 0){	// jQuery
 			switch (self::$jQueryVer){
 				case 0:		// デフォルトのとき
 					$filename = self::JQUERY_FILENAME;	// jquery
@@ -227,10 +228,12 @@ class ScriptLibInfo
 		// 使用するjQueryバージョンに合わせてファイルを追加
 		switch (self::$jQueryVer){
 			case 0:		// デフォルトのとき
+				$libs[self::LIB_JQUERY] = array(	'script' => array(self::getJQueryFilename(0)));	// jquery
 				$libs[self::LIB_JQUERY_UI] = array(	'script' => array(self::JQUERY_UI_CORE_FILENAME));	// jquery ui
 				$libs[self::LIB_JQUERY_UI_PLUS] = array(	'script' => array(self::JQUERY_UI_PLUS_FILENAME));	// jquery ui plus(追加分)
 				break;
 			case 1:		// 最新のとき
+				$libs[self::LIB_JQUERY] = array(	'script' => array(self::getJQueryFilename(0)));	// jquery
 				$libs[self::LIB_JQUERY_UI] = array(	'script' => array(self::JQUERY_L_UI_CORE_FILENAME));	// jquery ui
 				$libs[self::LIB_JQUERY_UI_PLUS] = array(	'script' => array(self::JQUERY_L_UI_PLUS_FILENAME));	// jquery ui plus(追加分)
 				
@@ -261,6 +264,7 @@ class ScriptLibInfo
 			if (self::$jQueryVer == 0){		// デフォルトのとき
 				$jQueryUiInfo = array();
 			} else {
+			/*
 				$jQueryUiInfo = array(
 					self::LIB_JQUERY_UI_WIDGETS_ACCORDION		=> array(self::LIB_JQUERY_UI),		// Widgets Accordion
 					self::LIB_JQUERY_UI_WIDGETS_AUTOCOMPLETE	=> array(self::LIB_JQUERY_UI),		// Widgets Autocomplete
@@ -273,6 +277,19 @@ class ScriptLibInfo
 					self::LIB_JQUERY_UI_WIDGETS_SLIDER			=> array(self::LIB_JQUERY_UI),		// Widgets Slider
 					self::LIB_JQUERY_UI_WIDGETS_TABS			=> array(self::LIB_JQUERY_UI),		// Widgets Tabs
 					self::LIB_JQUERY_UI_EFFECTS					=> array(self::LIB_JQUERY_UI)		// Effects
+				);*/
+				$defaultLib = array(self::LIB_JQUERY, self::LIB_JQUERY_UI);
+				$jQueryUiInfo = array(
+					self::LIB_JQUERY_UI_WIDGETS_ACCORDION		=> $defaultLib,		// Widgets Accordion
+					self::LIB_JQUERY_UI_WIDGETS_AUTOCOMPLETE	=> $defaultLib,		// Widgets Autocomplete
+					self::LIB_JQUERY_UI_WIDGETS_BUTTON			=> $defaultLib,		// Widgets Button
+					self::LIB_JQUERY_UI_WIDGETS_DATEPICKER		=> $defaultLib,		// Widgets Datepicker
+					self::LIB_JQUERY_UI_WIDGETS_DIALOG			=> array_merge($defaultLib,		// Widgets Dialog
+																			array(self::LIB_JQUERY_UI_PLUS, self::LIB_JQUERY_UI_WIDGETS_BUTTON)),
+					self::LIB_JQUERY_UI_WIDGETS_PROGRESSBAR		=> $defaultLib,		// Widgets Progressbar
+					self::LIB_JQUERY_UI_WIDGETS_SLIDER			=> $defaultLib,		// Widgets Slider
+					self::LIB_JQUERY_UI_WIDGETS_TABS			=> $defaultLib,		// Widgets Tabs
+					self::LIB_JQUERY_UI_EFFECTS					=> $defaultLib		// Effects
 				);
 			}
 		}
