@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 3631 2010-09-25 01:24:08Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 3677 2010-10-07 07:07:41Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -284,7 +284,11 @@ class BaseFrameContainer extends Core
 			$cacheData = $this->gCache->getPageCache($request);
 			
 			if (empty($cacheData)){		// キャッシュデータがないときは画面を作成
-				$pageData = $this->_createPage($request);
+				// カレントのテンプレートを決定
+				$curTemplateId = $this->_defineTemplate($request);
+		
+				// 画面を作成
+				$pageData = $this->_createPage($request, $curTemplateId);
 				$this->gCache->setPageCache($request, $pageData);		// キャッシュデータを設定
 				echo $pageData;
 			} else {
@@ -503,13 +507,11 @@ class BaseFrameContainer extends Core
 	 * 画面を作成
 	 *
 	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param string $curTemplate			テンプレートID
 	 * @return string						画面出力
 	 */
-	function _createPage($request)
+	function _createPage($request, $curTemplate)
 	{
-		// カレントのテンプレートを決定
-		$curTemplate = $this->_defineTemplate($request);
-
 		// カレントのテンプレートIDを設定
 		$this->gEnv->setCurrentTemplateId($curTemplate);
 
@@ -770,75 +772,22 @@ class BaseFrameContainer extends Core
 	function _showSystemPage($request)
 	{
 		// ページIDを設定
-		$pageId = 'admin_index';
+		$pageId = 'admin_index';		// 管理画面を表示
 		$this->gEnv->setCurrentPageId($pageId);								// ここでデフォルトページサブIDが再設定される
 		$this->gEnv->setCurrentPageSubId($this->gEnv->getDefaultPageSubId());// デフォルトページサブIDをカレントにする
 		
 		// テンプレートの設定
 		// DBで設定されている値を取得し、なければ管理用デフォルトテンプレートを使用
 		if ($this->gEnv->getIsMobileSite()){		// 携帯用サイトのアクセスの場合
-			$curTemplate = self::M_ADMIN_TEMPLATE;	// 携帯管理画面用テンプレート
+			$curTemplateId = self::M_ADMIN_TEMPLATE;	// 携帯管理画面用テンプレート
 		} else {
-			$curTemplate = $this->gSystem->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
-			if (empty($curTemplate)) $curTemplate = self::ADMIN_TEMPLATE;// 管理用テンプレート
+			$curTemplateId = $this->gSystem->getSystemConfig(self::CONFIG_KEY_MSG_TEMPLATE);
+			if (empty($curTemplateId)) $curTemplateId = self::ADMIN_TEMPLATE;// 管理用テンプレート
 		}
 
-		// カレントのテンプレートIDを設定
-		$this->gEnv->setCurrentTemplateId($curTemplate);
-		
-		// ################### バッファリング開始 ######################
-		// ob_end_flush()までの出力をバッファリングする
-		if ($this->gEnv->getIsMobileSite()){		// 携帯用サイトのアクセスの場合		
-			$mobileEncoding = $this->gEnv->getMobileEncoding();		// 携帯用エンコーディングを取得
-			mb_http_output($mobileEncoding);
-			ob_start("mb_output_handler"); // 出力のバッファリング開始
-		} else {
-			ob_start();
-		}
-
-		// サブクラスの前処理を実行
-		if (method_exists($this, '_preBuffer')) $this->_preBuffer($request);
-			
-		// Joomlaテンプレート用定義
-		global $mosConfig_absolute_path;
-		global $mosConfig_live_site;
-		global $mosConfig_sitename;
-		global $mosConfig_favicon;
-		global $mosConfig_sef;
-		global $cur_template;
-		global $mainframe;
-		require_once($this->gEnv->getJoomlaRootPath() . '/mosDef.php');// Joomla定義読み込み
-		require_once($this->gEnv->getJoomlaRootPath() . '/mosFunc.php');
-		require_once($this->gEnv->getJoomlaRootPath() . '/includes/sef.php');
-		
-		// ################### テンプレート読み込み ###################
-		// テンプレートのポジションタグからウィジェットが実行される
-		$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplate . '/index.php';
-		if (file_exists($templateIndexFile)){
-			require_once($templateIndexFile);
-		} else {
-			echo 'template not found error: ' . $curTemplate;
-		}
-		
-		// サブクラスの後処理の呼び出し
-		if (method_exists($this, '_postBuffer')) $this->_postBuffer($request);
-	
-		// 現在の出力内容を取得し、一旦内容をクリア
-		$srcContents = ob_get_contents();
-		ob_clean();
-		
-		// 遅延実行ウィジェットの出力を埋め込む
-		$destContents = $this->gPage->lateLaunchWidget($request, $srcContents);
-		echo $destContents;
-		
-		// ページ作成終了処理(HTTPヘッダ出力)
-		$this->gPage->endPage($request);
-	
-		// オプション出力(時間計測等)追加
-		echo $this->gPage->getOptionContents($request);
-				
-		// バッファ内容を送信(クライアントへの送信完了)
-		ob_end_flush();
+		// 画面を作成
+		$pageData = $this->_createPage($request, $curTemplateId);
+		echo $pageData;
 	}
 	/**
 	 * phpinfo画面表示
