@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 3548 2010-08-29 06:35:05Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 3663 2010-10-02 05:00:50Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -111,7 +111,7 @@ class BaseWidgetContainer extends Core
 			$templateFile = $this->_setTemplate($request, $param);
 			
 			// テンプレートファイル名が空文字列のときは、テンプレートライブラリを使用しない
-			if ($templateFile != ''){
+			if (!empty($templateFile)){
 				// テンプレートオブジェクト作成
 				$this->__setTemplate();
 				
@@ -220,7 +220,7 @@ class BaseWidgetContainer extends Core
 					$this->gPage->setHeadKeywords($headData['keywords']);
 				}
 			}
-			if ($templateFile != ''){
+			if (!empty($templateFile)){
 				// エラーメッセージ出力
 				if ($this->displayMessage) $this->displayMsg();
 	
