@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 1.16.x SVN: $Id: global.php 3667 2010-10-04 07:49:50Z fishbone $
+ * @version    Release 1.16.x SVN: $Id: global.php 3682 2010-10-08 23:08:58Z fishbone $
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -43,8 +43,8 @@ define('M3_ENCODING',	'UTF-8');	// 内部エンコーディング
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'1.16.0');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2010/9/30');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'1.16.1');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2010/10/4');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -107,7 +107,9 @@ define('M3_VIEW_TYPE_BLOG',			'blog');				// ブログ
 define('M3_VIEW_TYPE_WIKI',			'wiki');				// wiki
 define('M3_VIEW_TYPE_USER',			'user');				// ユーザ作成コンテンツ
 define('M3_VIEW_TYPE_DASHBOARD',	'dboard');				// ダッシュボード
-define('M3_VIEW_TYPE_SYSTEM',		'system');				// システム用
+
+// コンテンツ取得用キー
+define('M3_CONTENT_KEY_MAINTENANCE',	'MAINTENANCE');				// メンテナンス画面用
 
 // ウィジェットタイプ
 define('M3_WIDGET_TYPE_MENU',	'menu');				// メニュー
