@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInitdbWidgetContainer.php 2834 2010-02-05 04:42:26Z fishbone $
+ * @version    SVN: $Id: _installInitdbWidgetContainer.php 3641 2010-09-27 09:55:22Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -22,6 +22,7 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 	private $sysDb;	// DB接続オブジェクト
 	private $createTableScripts;			// テーブル作成スクリプト
 	private $insertTableScripts;			// データインストールスクリプト
+	private $updateTableScripts;			// テーブル更新スクリプト
 	const CF_SERVER_ID = 'server_id';
 	const CF_SERVER_URL = 'server_url';		// サーバURL
 	const INSTALL_DT = 'install_dt';		// システムインストール日時
@@ -42,7 +43,7 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		$this->sysDb = $this->gInstance->getSytemDbObject();
 		
 		// 実行SQLスクリプトファイルの定義
-		$this->createTableScripts = array(	array(	'filename' 		=> 'create_base.sql',					// ファイル名
+/*		$this->createTableScripts = array(	array(	'filename' 		=> 'create_base.sql',					// ファイル名
 													'name'			=> 'システム基本テーブル作成',				// 表示名
 													'description'	=> 'システムで最小限必要なテーブルの作成'),	// 説明
 											array(	'filename' 		=> 'create_std.sql',					// ファイル名
@@ -58,6 +59,7 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 											array(	'filename' 		=> 'insert_std.sql',					// ファイル名
 													'name'			=> 'システム標準データ登録',				// 表示名
 													'description'	=> 'システムを通常使用するのに必要なデータの登録'));	// 説明
+													*/
 													
 		// デバッグモードで起動している場合はテスト用スクリプト追加
 		if (M3_SYSTEM_DEBUG){
@@ -113,25 +115,13 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		$from = $request->trimValueOf('from');
 		
 		if ($act == 'done'){
-			// 初期化情報読み込み
-			$installInfoFile = M3_SYSTEM_INCLUDE_PATH . '/install/installInfo.php';
-			if (file_exists($installInfoFile)){
-				require_once($installInfoFile);
-				$infoClass = self::INSTALL_INFO_CLASS;
-				$installInfo = new $infoClass;
-			} else {
-				// デフォルトを検索
-				$installInfoFile = M3_SYSTEM_INCLUDE_PATH . '/install/installInfo_default.php';
-				if (file_exists($installInfoFile)){
-					require_once($installInfoFile);
-					$infoClass = self::INSTALL_INFO_CLASS;
-					$installInfo = new $infoClass;
-				}
-			}
+			// インストール情報オブジェクト取得
+			$installInfo = $this->getInstallInfo();
 			if (isset($installInfo)){
 				// テーブル作成、初期化スクリプト情報取得
 				$this->createTableScripts = $installInfo->getCreateTableScripts();
 				$this->insertTableScripts = $installInfo->getInsertTableScripts();
+				$this->updateTableScripts = $installInfo->getUpdateTableScripts();			// テーブル更新スクリプト
 			}
 			
 			// ##### SQLスクリプトを実行 #####
@@ -223,6 +213,17 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 			// トランザクション終了
 			//$this->gDb->endTransaction();// PostgreSQLでは途中で落ちるのではずす
 			
+			// ウィジェット情報を更新
+			if ($ret){
+				for ($i = 0; $i < count($this->updateTableScripts); $i++){
+					$ret = $this->gInstance->getDbManager()->execInitScriptFile($this->updateTableScripts[$i]['filename'], $errors);
+					if (!$ret){
+						$filename = $this->updateTableScripts[$i]['filename'];
+						break;// 異常終了の場合
+					}
+				}
+			}
+			
 			if ($ret){// 正常終了の場合
 				// DBのバージョン取得
 				$currentVer = $this->sysDb->getSystemConfig(M3_TB_FIELD_DB_VERSION);
@@ -280,63 +281,79 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		$type = $request->trimValueOf('install_type');
 		
 		if ($act == 'done'){
-			if ($this->getUpdateScriptCount() > 0){
-				// タイムアウトを停止
-				$this->gPage->setNoTimeout();
+			// インストール情報オブジェクト取得
+			$installInfo = $this->getInstallInfo();
+			if (isset($installInfo)){
+				// テーブル作成、初期化スクリプト情報取得
+				$this->createTableScripts = $installInfo->getCreateTableScripts();
+				$this->insertTableScripts = $installInfo->getInsertTableScripts();
+				$this->updateTableScripts = $installInfo->getUpdateTableScripts();			// テーブル更新スクリプト
+			}
+			// 更新スクリプトがあるかどうか
+			$updateDb = false;
+			if ($this->getUpdateScriptCount() > 0) $updateDb = true;
 			
-				// テーブルのパッチを当てる
+			// タイムアウトを停止
+			$this->gPage->setNoTimeout();
+		
+			// テーブルのパッチを当てる
+			if ($updateDb){
 				$ret = $this->updateDb($filename, $updateErrors);
-			
-				if ($ret){// 正常終了の場合
-					// デフォルト値設定
-					
-					// 更新日時を設定
-					$now = date("Y/m/d H:i:s");	// 現在日時
-					$this->sysDb->updateSystemConfig(M3_TB_FIELD_DB_UPDATE_DT, $now);
-				
-					// システム初期化を不可に設定(インストール終了)
-					$this->gSystem->disableInitSystem();
-				
-					// ログ出力
-					$currentVer = $this->sysDb->getSystemConfig(M3_TB_FIELD_DB_VERSION);
-					$this->gOpeLog->writeInfo(__METHOD__, 'DB更新処理が正常に終了しました。現在のDBバージョン: ' . $currentVer, 1000);
-				
-					$type = 'all';
-					//$this->gPage->redirect('?task=initother&install_type=' . $type . '&from=updatedb');
-					$this->gPage->redirect('?task=copyfile&install_type=' . $type . '&from=updatedb');
-				} else {
-					// エラーメッセージ追加
+			} else {
+				$ret = true;
+			}
+		
+			// ウィジェット情報を更新(共通処理)
+			if ($ret){
+				for ($i = 0; $i < count($this->updateTableScripts); $i++){
+					$ret = $this->gInstance->getDbManager()->execInitScriptFile($this->updateTableScripts[$i]['filename'], $errors);
 					if (!$ret){
-						if (!isset($errors)) $errors = array();
-						array_splice($errors, count($errors), 0, $updateErrors);
-					}
-					
-					$msg = 'DB更新に失敗しました';
-					if (!empty($filename)) $msg .= '(スクリプト名=' . $filename . ')';
-					$this->setMsg(self::MSG_APP_ERR, $msg);
-				
-					// ログ出力
-					$this->gOpeLog->writeError(__METHOD__, $msg, 1100);
-				}
-				// エラーメッセージを画面に表示
-				if (!empty($errors)){
-					foreach ($errors as $error) {
-						$this->setMsg(self::MSG_APP_ERR, $error);
+						$filename = $this->updateTableScripts[$i]['filename'];
+						break;// 異常終了の場合
 					}
 				}
-			} else {		// DB更新用スクリプトファイルがないとき
+			}
+			if ($ret){// 正常終了の場合
 				// デフォルト値設定
 				
+				// 更新日時を設定
+				if ($updateDb){
+					$now = date("Y/m/d H:i:s");	// 現在日時
+					$this->sysDb->updateSystemConfig(M3_TB_FIELD_DB_UPDATE_DT, $now);
+				}
+			
 				// システム初期化を不可に設定(インストール終了)
 				$this->gSystem->disableInitSystem();
 			
 				// ログ出力
 				$currentVer = $this->sysDb->getSystemConfig(M3_TB_FIELD_DB_VERSION);
-				$this->gOpeLog->writeInfo(__METHOD__, 'DBを更新する必要はありません。DBバージョン: ' . $currentVer, 1000);
+				if ($updateDb){		// DB更新処理ありの場合
+					$this->gOpeLog->writeInfo(__METHOD__, 'DB更新処理が正常に終了しました。現在のDBバージョン: ' . $currentVer, 1000);
+				} else {
+					$this->gOpeLog->writeInfo(__METHOD__, 'ウィジェット情報を更新しました。DBバージョン: ' . $currentVer, 1000);
+				}
 			
 				$type = 'all';
-				//$this->gPage->redirect('?task=initother&install_type=' . $type . '&from=updatedb');
 				$this->gPage->redirect('?task=copyfile&install_type=' . $type . '&from=updatedb');
+			} else {
+				// エラーメッセージ追加
+				if (!$ret){
+					if (!isset($errors)) $errors = array();
+					array_splice($errors, count($errors), 0, $updateErrors);
+				}
+				
+				$msg = 'DB更新に失敗しました';
+				if (!empty($filename)) $msg .= '(スクリプト名=' . $filename . ')';
+				$this->setMsg(self::MSG_APP_ERR, $msg);
+			
+				// ログ出力
+				$this->gOpeLog->writeError(__METHOD__, $msg, 1100);
+			}
+			// エラーメッセージを画面に表示
+			if (!empty($errors)){
+				foreach ($errors as $error) {
+					$this->setMsg(self::MSG_APP_ERR, $error);
+				}
 			}
 		}
 			
@@ -451,5 +468,31 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		sort($files);
 		return $files;
 	}
+	/**
+	 * インストール情報オブジェクト取得
+	 *
+	 * @return object		インストール情報オブジェクト
+	 */
+	function getInstallInfo()
+	{
+		$infoObj = null;
+		
+		// 初期化情報読み込み
+		$installInfoFile = M3_SYSTEM_INCLUDE_PATH . '/install/installInfo.php';
+		if (file_exists($installInfoFile)){
+			require_once($installInfoFile);
+			$infoClass = self::INSTALL_INFO_CLASS;
+			$infoObj = new $infoClass;
+		} else {
+			// デフォルトを検索
+			$installInfoFile = M3_SYSTEM_INCLUDE_PATH . '/install/installInfo_default.php';
+			if (file_exists($installInfoFile)){
+				require_once($installInfoFile);
+				$infoClass = self::INSTALL_INFO_CLASS;
+				$infoObj = new $infoClass;
+			}
+		}
+		return $infoObj;
+	}
 }
 ?>
