@@ -10,15 +10,21 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 3544 2010-08-28 07:09:38Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 3680 2010-10-08 09:04:04Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 
 class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 {
 	private $redirectUrl;		// リダイレクト先URL
-
+	private $content;			// メッセージ用コンテンツ
+	private $headTitle;		// METAタグタイトル
+	private $headDesc;		// METAタグ要約
+	private $headKeyword;	// METAタグキーワード
+	const CF_USE_CONTENT_MAINTENANCE = 'use_content_maintenance';		// メンテナンス画面に汎用コンテンツを使用するかどうか
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -58,13 +64,33 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 						$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){		// 表示位置を表示するとき(ウィジェット付き)
 				$param = 'userlogin';			// ユーザログイン画面表示
 				$this->redirectUrl = $this->gEnv->getCurrentRequestUri();		// 遷移先
-			} else {
-				// 現在の言語でメッセージ取得
-				$msg = $this->gInstance->getMessageManager()->getMessage(MessageManager::MSG_SITE_IN_MAINTENANCE);
+			} else {		// メンテナンス画面の表示のとき
+				$createMessage = false;		// メッセージを作成したかどうか
+				$value = $this->gSystem->getSystemConfig(self::CF_USE_CONTENT_MAINTENANCE);
+				if (!empty($value)){		// 汎用コンテンツを使用するとき
+					// コンテンツタイプを取得
+					$contentType = $this->getContentType();
+					
+					$db = new admin_mainDb();
+					$ret = $db->getContentByKey($contentType, $this->gEnv->getCurrentLanguage(), M3_CONTENT_KEY_MAINTENANCE, $row);
+					if ($ret && !empty($row['cn_html'])){
+						$createMessage = true;		// メッセージを作成したかどうか
+						
+						$this->content = $row['cn_html'];
+						$this->headTitle = $row['cn_meta_title'];
+						$this->headDesc = $row['cn_meta_description'];
+						$this->headKeyword = $row['cn_meta_keywords'];
+						$param = 'content';			// コンテンツ画面表示
+					}
+				}
 				
-				$this->SetMsg(self::MSG_APP_ERR, $msg);
-				$param = 'message';			// メッセージ画面表示
+				if (!$createMessage){		// メッセージを作成したかどうか
+					// 現在の言語でメッセージ取得
+					$msg = $this->gInstance->getMessageManager()->getMessage(MessageManager::MSG_SITE_IN_MAINTENANCE);
 				
+					$this->SetMsg(self::MSG_APP_ERR, $msg);
+					$param = 'message';			// メッセージ画面表示
+				}
 				// メンテナンスモードに設定
 				$this->gEnv->setIsMaintenance(true);
 			}
@@ -228,10 +254,13 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function _setTemplate($request, &$param)
 	{
-		if ($param == 'message'){		// メッセージ表示のとき
-			return 'message.tmpl.html';
-		} else {						// ユーザログイン画面
-			return 'userlogin.tmpl.html';
+		switch ($param){
+			case 'message':		// メッセージ表示のとき	
+				return 'message.tmpl.html';
+			case 'content':		// コンテンツ表示のとき
+				return 'content.tmpl.html';
+			default:						// ユーザログイン画面
+				return 'userlogin.tmpl.html';
 		}
 	}
 	/**
@@ -245,9 +274,53 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		if (!empty($this->redirectUrl)){		// 遷移先
-			$this->tmpl->setAttribute('redirect_url', 'visibility', 'visible');
-			$this->tmpl->addVar('redirect_url', 'url', $this->convertToDispString($this->redirectUrl));
+		switch ($param){
+			case 'message':		// メッセージ表示のとき	
+				break;
+			case 'content':		// コンテンツ表示のとき
+				$this->tmpl->addVar("_widget", "content", $this->content);			// メンテナンスコンテンツ
+				break;
+			default:						// ユーザログイン画面
+				if (!empty($this->redirectUrl)){		// 遷移先
+					$this->tmpl->setAttribute('redirect_url', 'visibility', 'visible');
+					$this->tmpl->addVar('redirect_url', 'url', $this->convertToDispString($this->redirectUrl));
+				}
+				break;
+		}
+	}
+	/**
+	 * ヘッダ部メタタグの設定
+	 *
+	 * HTMLのheadタグ内に出力する。
+	 * _assign()よりも後に実行される。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ
+	 * @return array 						設定データ。連想配列で「title」「description」「keywords」を設定。
+	 */
+	function _setHeadMeta($request, &$param)
+	{
+		$headData = array(	'title' => $this->headTitle,
+							'description' => $this->headDesc,
+							'keywords' => $this->headKeyword);
+		return $headData;
+	}
+	/**
+	 * アクセスポイントから汎用コンテンツのタイプを取得
+	 *
+	 * @return string		汎用コンテンツデータタイプ
+	 */
+	function getContentType()
+	{
+		// PC用サイト、携帯用サイト、スマートフォン用サイトを判断
+		if ($this->gEnv->getIsPcSite()){
+			return '';
+		} else if ($this->gEnv->getIsMobileSite()){
+			return 'mobile';
+		} else if ($this->gEnv->getIsSmartphoneSite()){
+			return 'smartphone';
+		} else {
+			return '';
 		}
 	}
 }
