@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 3597 2010-09-17 01:41:17Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 3680 2010-10-08 09:04:04Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -1510,15 +1510,17 @@ class admin_mainDb extends BaseDb
 	/**
 	 * テンプレートリスト取得
 	 *
-	 * @param int      $type		テンプレートのタイプ(0=PC用、1=携帯用、2=スマートフォン)
-	 * @param function $callback	コールバック関数
-	 * @return						なし
+	 * @param int      $type			テンプレートのタイプ(0=PC用、1=携帯用、2=スマートフォン)
+	 * @param function $callback		コールバック関数
+	 * @param bool     $availableOnly	利用可能なテンプレートに制限するかどうか
+	 * @return							なし
 	 */
-	function getAllTemplateList($type, $callback)
+	function getAllTemplateList($type, $callback, $availableOnly = true)
 	{
 		// tm_device_typeは後で追加したため、tm_mobileを残しておく
 		$queryStr = 'SELECT * FROM _templates ';
 		$queryStr .=  'WHERE tm_deleted = false ';// 削除されていない
+		if ($availableOnly) $queryStr .=    'AND tm_available = true ';		// 利用可能
 		$params = array();
 		switch ($type){
 			case 0:		// PC用テンプレート
@@ -2541,6 +2543,26 @@ class admin_mainDb extends BaseDb
 		$queryStr .=  'ORDER BY cn_id';
 		$this->selectLoop($queryStr, array($contentType, $lang), $callback, null);
 	}
+	/**
+	 * 汎用コンテンツを外部キーで取得
+	 *
+	 * @param string	$contentType		コンテンツタイプ
+	 * @param string	$langId				言語ID
+	 * @param string	$key				外部キー
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getContentByKey($contentType, $langId, $key, &$row)
+	{
+		$queryStr  = 'SELECT * FROM content ';
+		$queryStr .=   'WHERE cn_deleted = false ';	// 削除されていない
+		$queryStr .=     'AND cn_type = ? ';
+		$queryStr .=     'AND cn_language_id = ? ';
+		$queryStr .=     'AND cn_key = ? ';
+		$queryStr .=   'ORDER BY cn_id';
+		$ret = $this->selectRecord($queryStr, array($contentType, $langId, $key), $row);
+		return $ret;
+	}
 	/**
 	 * メニューIDのリストを取得
 	 *
