@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 3575 2010-09-10 03:07:02Z fishbone $
+ * @version    SVN: $Id: index.php 3597 2010-09-17 01:41:17Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -65,23 +65,23 @@ $HELP['userlist']['body'] = 'システムで一元管理するユーザの一覧
 $HELP['userlist_check']['title'] = '選択用チェックボックス';
 $HELP['userlist_check']['body'] = '編集や削除を行う項目を選択します。';
 $HELP['userlist_account']['title'] = 'ユーザアカウント';
-$HELP['userlist_account']['body'] = 'ログイン時に使用するアカウントです。<br>メールアドレス形式のアカウントも使用できます。';
+$HELP['userlist_account']['body'] = 'ログイン時に使用するアカウントです。<br />メールアドレス形式のアカウントも使用できます。';
 $HELP['userlist_pwd']['title'] = 'ユーザパスワード';
 $HELP['userlist_pwd']['body'] = 'ログイン時に使用するパスワードです。';
 $HELP['userlist_name']['title'] = '名前';
 $HELP['userlist_name']['body'] = '画面上に表示されるユーザの名前です。';
 $HELP['userlist_usertype']['title'] = 'ユーザ種別';
-$HELP['userlist_usertype']['body'] = '管理者 - 管理機能にログインできます。<br>一般 - 管理機能以外の機能にログインできます。<br>仮登録 - 一般機能からユーザ登録を行い、まだログインしていないユーザです。一度ログインすると一般ユーザに変更されます。';
+$HELP['userlist_usertype']['body'] = '管理者 - すべての管理機能が使用可能です。<br />運営者 - 制限された管理機能が使用可能です。<br />投稿者 - サイトにログインでき、ブログ等の記事の投稿が可能です。<br />一般 - サイトにログインできます。<br />仮登録 - 一般機能からユーザ登録を行い、まだログインしていないユーザです。一度ログインすると一般ユーザに変更されます。<br />未承認 - 承認を申請し、まだ承認されていないユーザです。';
 $HELP['userlist_admin']['title'] = '管理権限';
-$HELP['userlist_admin']['body'] = '管理機能(管理画面)が使用可能かどうかの設定です。<br>チェックが入っていると管理機能が使用可能です。';
+$HELP['userlist_admin']['body'] = '管理機能(管理画面)が使用可能かどうかの設定です。<br />チェックが入っていると管理機能が使用可能です。';
 $HELP['userlist_login']['title'] = 'ログイン可';
-$HELP['userlist_login']['body'] = 'ログインを許可するかどうかの設定です。<br>チェックが入っているとログイン可能です。';
+$HELP['userlist_login']['body'] = 'ログインを許可するかどうかの設定です。<br />チェックが入っているとログイン可能です。';
 $HELP['userlist_new_btn']['title'] = '新規ボタン';
 $HELP['userlist_new_btn']['body'] = '新規ユーザを追加します。';
 $HELP['userlist_edit_btn']['title'] = '編集ボタン';
-$HELP['userlist_edit_btn']['body'] = '選択されているユーザを編集します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['userlist_edit_btn']['body'] = '選択されているユーザを編集します。<br />ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['userlist_del_btn']['title'] = '削除ボタン';
-$HELP['userlist_del_btn']['body'] = '選択されているユーザを削除します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['userlist_del_btn']['body'] = '選択されているユーザを削除します。<br />ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['userlist_ret_btn']['title'] = '戻るボタン';
 $HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';
 
@@ -153,7 +153,7 @@ $HELP['pagedef_template_img']['body'] = 'テンプレートを設定した場合
 $HELP['pagedef_widget']['title'] = 'ウィジェット';
 $HELP['pagedef_widget']['body'] = 'レイアウトに配置可能なウィジェットです。シングルクリックで取得し、画面レイアウト領域に配置します。';
 $HELP['pagedef_layout']['title'] = '画面レイアウト';
-$HELP['pagedef_layout']['body'] = '(ウィジェットの配置)<br>テンプレートにウィジェットを配置し、画面を作成します。ウィジェット一覧からマウスドラッグでウィジェットを取り出します。レイアウト画面の任意のポジション位置にドロップするとウィジェットが配置できます。レイアウト画面からウィジェットを削除するには、削除するウィジェットの右上のクローズボックスをクリックします。一度ドロップしたウィジェットは、ドラッグドロップでページ上の移動が可能です。最大化ボタンまたはESCキーでレイアウト画面が最大化できます。最大化状態から元に戻るにはESCキーを押します。<br>(ウィジェットコンテキストメニュー)<br>ウィジェットをマウス右クリックするとコンテキストメニューが表示されます。ウィジェットの設定を行ったり、ウィジェットの削除を行います。「ページ共通」属性を設定したウィジェットは、ページに関わらず常に表示されます。(赤色表示)';
+$HELP['pagedef_layout']['body'] = '(ウィジェットの配置)<br />テンプレートにウィジェットを配置し、画面を作成します。ウィジェット一覧からマウスドラッグでウィジェットを取り出します。レイアウト画面の任意のポジション位置にドロップするとウィジェットが配置できます。レイアウト画面からウィジェットを削除するには、削除するウィジェットの右上のクローズボックスをクリックします。一度ドロップしたウィジェットは、ドラッグドロップでページ上の移動が可能です。最大化ボタンまたはESCキーでレイアウト画面が最大化できます。最大化状態から元に戻るにはESCキーを押します。<br />(ウィジェットコンテキストメニュー)<br />ウィジェットをマウス右クリックするとコンテキストメニューが表示されます。ウィジェットの設定を行ったり、ウィジェットの削除を行います。「ページ共通」属性を設定したウィジェットは、ページに関わらず常に表示されます。(赤色表示)';
 $HELP['pagedef_preview']['title'] = 'レイアウトとプレビューの切り替えボタン';
 $HELP['pagedef_preview']['body'] = 'ウィジェットの配置を行うレイアウト画面と、実際に表示されるプレビュー画面を切り替えます。';
 $HELP['pagedef_refresh']['title'] = '画面再表示';
@@ -175,9 +175,9 @@ $HELP['pagedef_widget_common']['body'] = '同ページIDで、サブページID
 $HELP['edittable_new_btn']['title'] = '新規ボタン';
 $HELP['edittable_new_btn']['body'] = '新規レコードを追加します。';
 $HELP['edittable_edit_btn']['title'] = '編集ボタン';
-$HELP['edittable_edit_btn']['body'] = '選択されているレコードを編集します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['edittable_edit_btn']['body'] = '選択されているレコードを編集します。<br />レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['edittable_del_btn']['title'] = '削除ボタン';
-$HELP['edittable_del_btn']['body'] = '選択されているレコードを削除します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['edittable_del_btn']['body'] = '選択されているレコードを削除します。<br />レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['edittable_ret_btn']['title'] = '戻るボタン';
 $HELP['edittable_ret_btn']['body'] = 'レコード一覧へ戻ります。';
 
@@ -218,7 +218,7 @@ $HELP['usercustom_value']['body'] = 'コンテンツ表示時に、コンテン
 $HELP['pageinfo']['title'] = 'ページ情報';
 $HELP['pageinfo']['body'] = 'サイトのアクセス単位であるページについての情報を設定します。';
 $HELP['pageinfo_list']['title'] = 'ページ情報一覧';
-$HELP['pageinfo_list']['body'] = 'ページはアクセスポイントである「ページID」とサブパラメータの「ページサブID」のセットで一意に決まります。<br>ページサブIDはURLのクエリーパラメータ「sub=サブページID」で指定されるIDです。';
+$HELP['pageinfo_list']['body'] = 'ページはアクセスポイントである「ページID」とサブパラメータの「ページサブID」のセットで一意に決まります。<br />ページサブIDはURLのクエリーパラメータ「sub=サブページID」で指定されるIDです。';
 $HELP['pageinfo_detail']['title'] = 'ページ情報詳細';
 $HELP['pageinfo_detail']['body'] = 'ページ情報を編集します。';
 
@@ -238,12 +238,14 @@ $HELP['pageinfo_public']['title'] = '公開';
 $HELP['pageinfo_public']['body'] = '管理者以外のユーザがアクセス可能であるかどうかを示します。';
 $HELP['pageinfo_ssl']['title'] = 'SSL';
 $HELP['pageinfo_ssl']['body'] = 'SSLを使用してページを表示するかどうかを設定します。';
+$HELP['pageinfo_user_limited']['title'] = 'ユーザ制限';
+$HELP['pageinfo_user_limited']['body'] = 'ページにアクセスできるユーザをログインしたユーザに制限するかどうかを設定します。チェックが入っている場合は、ログインユーザのみがアクセス可能です。';
 $HELP['pageinfo_default']['title'] = 'デフォルト';
 $HELP['pageinfo_default']['body'] = 'デフォルトで選択されている項目は、ページサブIDが省略されたときに指定されるページサブIDです。';
 $HELP['pageinfo_ref']['title'] = '使用';
 $HELP['pageinfo_ref']['body'] = 'ページ上に存在するウィジェット数です。共通属性が設定されているウィジェットは含みません。';
 $HELP['pageinfo_edit_btn']['title'] = '編集ボタン';
-$HELP['pageinfo_edit_btn']['body'] = '選択されているページサブIDの情報を編集します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['pageinfo_edit_btn']['body'] = '選択されているページサブIDの情報を編集します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['pageinfo_ret_btn']['title'] = '戻るボタン';
 $HELP['pageinfo_ret_btn']['body'] = 'ページ情報一覧へ戻ります。';
 
@@ -251,7 +253,7 @@ $HELP['pageinfo_ret_btn']['body'] = 'ページ情報一覧へ戻ります。';
 $HELP['pagehead']['title'] = 'ページヘッダ情報';
 $HELP['pagehead']['body'] = 'HTMLのヘッダ部のmetaタグに出力する文字列を設定します。';
 $HELP['pagehead_list']['title'] = 'ページヘッダ情報一覧';
-$HELP['pagehead_list']['body'] = 'ページはアクセスポイントである「ページID」とサブパラメータの「ページサブID」のセットで一意に決まります。<br>ページサブIDはURLのクエリーパラメータ「sub=サブページID」で指定されるIDです。';
+$HELP['pagehead_list']['body'] = 'ページはアクセスポイントである「ページID」とサブパラメータの「ページサブID」のセットで一意に決まります。<br />ページサブIDはURLのクエリーパラメータ「sub=サブページID」で指定されるIDです。';
 $HELP['pagehead_detail']['title'] = 'ページヘッダ情報詳細';
 $HELP['pagehead_detail']['body'] = 'ページヘッダ情報を編集します。';
 
@@ -274,7 +276,7 @@ $HELP['pagehead_public']['body'] = '管理者以外のユーザがアクセス
 $HELP['pagehead_default']['title'] = 'デフォルト';
 $HELP['pagehead_default']['body'] = 'デフォルトで選択されている項目は、ページサブIDが省略されたときに使用されるページサブIDです。';
 $HELP['pagehead_edit_btn']['title'] = '編集ボタン';
-$HELP['pagehead_edit_btn']['body'] = '選択されているページサブIDの情報を編集します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['pagehead_edit_btn']['body'] = '選択されているページサブIDの情報を編集します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['pagehead_ret_btn']['title'] = '戻るボタン';
 $HELP['pagehead_ret_btn']['body'] = 'ページ情報一覧へ戻ります。';
 
@@ -302,9 +304,9 @@ $HELP['pageid_active']['body'] = 'ページIDを一般ユーザに公開する
 $HELP['pageid_new_btn']['title'] = '新規ボタン';
 $HELP['pageid_new_btn']['body'] = '新規ページIDを追加します。';
 $HELP['pageid_edit_btn']['title'] = '編集ボタン';
-$HELP['pageid_edit_btn']['body'] = '選択されているページIDを編集します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['pageid_edit_btn']['body'] = '選択されているページIDを編集します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['pageid_del_btn']['title'] = '削除ボタン';
-$HELP['pageid_del_btn']['body'] = '選択されているページIDを削除します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['pageid_del_btn']['body'] = '選択されているページIDを削除します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['pageid_ret_btn']['title'] = '戻るボタン';
 $HELP['pageid_ret_btn']['body'] = 'ページID一覧へ戻ります。';
 
@@ -330,7 +332,7 @@ $HELP['menuid_ref']['body'] = 'メニューIDを使用しているウィジェ
 $HELP['menuid_new_btn']['title'] = '新規ボタン';
 $HELP['menuid_new_btn']['body'] = '新規メニューIDを追加します。';
 $HELP['menuid_edit_btn']['title'] = '編集ボタン';
-$HELP['menuid_edit_btn']['body'] = '選択されているメニューIDを編集します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['menuid_edit_btn']['body'] = '選択されているメニューIDを編集します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['menuid_del_btn']['title'] = '削除ボタン';
 $HELP['menuid_del_btn']['body'] = '選択されているメニューIDを削除します。<br />メニューIDを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['menuid_ret_btn']['title'] = '戻るボタン';
@@ -362,7 +364,7 @@ $HELP['opelog_message_check']['body'] = 'メッセージの確認状況を示し
 $HELP['opelog_message_dt']['title'] = '日時';
 $HELP['opelog_message_dt']['body'] = 'ログを出力した日時です。';
 $HELP['opelog_edit_btn']['title'] = '編集ボタン';
-$HELP['opelog_edit_btn']['body'] = '選択されている運用ログを編集します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['opelog_edit_btn']['body'] = '選択されている運用ログを編集します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['opelog_ret_btn']['title'] = '戻るボタン';
 $HELP['opelog_ret_btn']['body'] = '運用ログ一覧へ戻ります。';
 
@@ -402,7 +404,7 @@ $HELP['accesslog_user']['body'] = 'クッキーからユーザが識別可能な
 $HELP['accesslog_dt']['title'] = '日時';
 $HELP['accesslog_dt']['body'] = 'ログを出力した日時です。';
 $HELP['accesslog_edit_btn']['title'] = '編集ボタン';
-$HELP['accesslog_edit_btn']['body'] = '選択されているアクセスログの詳細を参照します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['accesslog_edit_btn']['body'] = '選択されているアクセスログの詳細を参照します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['accesslog_ret_btn']['title'] = '戻るボタン';
 $HELP['accesslog_ret_btn']['body'] = 'アクセスログ一覧へ戻ります。';
 
@@ -434,7 +436,7 @@ $HELP['searchwordlog_user']['body'] = 'クッキーからユーザが識別可
 $HELP['searchwordlog_dt']['title'] = '日時';
 $HELP['searchwordlog_dt']['body'] = 'ログを出力した日時です。';
 $HELP['searchwordlog_edit_btn']['title'] = '編集ボタン';
-$HELP['searchwordlog_edit_btn']['body'] = '選択されている検索語ログの詳細を参照します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['searchwordlog_edit_btn']['body'] = '選択されている検索語ログの詳細を参照します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['searchwordlog_ret_btn']['title'] = '戻るボタン';
 $HELP['searchwordlog_ret_btn']['body'] = '検索語ログ一覧へ戻ります。';
 
@@ -536,7 +538,7 @@ $HELP['tenantserver_test_db']['body'] = 'DB接続情報でDB接続をテスト
 $HELP['tenantserver_new_btn']['title'] = '新規ボタン';
 $HELP['tenantserver_new_btn']['body'] = '新規にサーバ情報を追加します。';
 $HELP['tenantserver_edit_btn']['title'] = '編集ボタン';
-$HELP['tenantserver_edit_btn']['body'] = '選択されているサーバ情報を編集します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['tenantserver_edit_btn']['body'] = '選択されているサーバ情報を編集します。<br />選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['tenantserver_del_btn']['title'] = '削除ボタン';
 $HELP['tenantserver_del_btn']['body'] = '選択されているサーバ情報を削除します。<br />サーバ情報を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['tenantserver_ret_btn']['title'] = '戻るボタン';
